# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ItemForListClustersOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'charge_type': 'str',
        'cluster_config': 'ClusterConfigForListClustersOutput',
        'create_client_token': 'str',
        'create_time': 'str',
        'delete_protection_enabled': 'bool',
        'description': 'str',
        'id': 'str',
        'kubernetes_version': 'str',
        'name': 'str',
        'node_statistics': 'NodeStatisticsForListClustersOutput',
        'pods_config': 'PodsConfigForListClustersOutput',
        'services_config': 'ServicesConfigForListClustersOutput',
        'status': 'StatusForListClustersOutput',
        'tags': 'list[TagForListClustersOutput]',
        'update_client_token': 'str',
        'update_time': 'str'
    }

    attribute_map = {
        'charge_type': 'ChargeType',
        'cluster_config': 'ClusterConfig',
        'create_client_token': 'CreateClientToken',
        'create_time': 'CreateTime',
        'delete_protection_enabled': 'DeleteProtectionEnabled',
        'description': 'Description',
        'id': 'Id',
        'kubernetes_version': 'KubernetesVersion',
        'name': 'Name',
        'node_statistics': 'NodeStatistics',
        'pods_config': 'PodsConfig',
        'services_config': 'ServicesConfig',
        'status': 'Status',
        'tags': 'Tags',
        'update_client_token': 'UpdateClientToken',
        'update_time': 'UpdateTime'
    }

    def __init__(self, charge_type=None, cluster_config=None, create_client_token=None, create_time=None, delete_protection_enabled=None, description=None, id=None, kubernetes_version=None, name=None, node_statistics=None, pods_config=None, services_config=None, status=None, tags=None, update_client_token=None, update_time=None, _configuration=None):  # noqa: E501
        """ItemForListClustersOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._charge_type = None
        self._cluster_config = None
        self._create_client_token = None
        self._create_time = None
        self._delete_protection_enabled = None
        self._description = None
        self._id = None
        self._kubernetes_version = None
        self._name = None
        self._node_statistics = None
        self._pods_config = None
        self._services_config = None
        self._status = None
        self._tags = None
        self._update_client_token = None
        self._update_time = None
        self.discriminator = None

        if charge_type is not None:
            self.charge_type = charge_type
        if cluster_config is not None:
            self.cluster_config = cluster_config
        if create_client_token is not None:
            self.create_client_token = create_client_token
        if create_time is not None:
            self.create_time = create_time
        if delete_protection_enabled is not None:
            self.delete_protection_enabled = delete_protection_enabled
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if kubernetes_version is not None:
            self.kubernetes_version = kubernetes_version
        if name is not None:
            self.name = name
        if node_statistics is not None:
            self.node_statistics = node_statistics
        if pods_config is not None:
            self.pods_config = pods_config
        if services_config is not None:
            self.services_config = services_config
        if status is not None:
            self.status = status
        if tags is not None:
            self.tags = tags
        if update_client_token is not None:
            self.update_client_token = update_client_token
        if update_time is not None:
            self.update_time = update_time

    @property
    def charge_type(self):
        """Gets the charge_type of this ItemForListClustersOutput.  # noqa: E501


        :return: The charge_type of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this ItemForListClustersOutput.


        :param charge_type: The charge_type of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._charge_type = charge_type

    @property
    def cluster_config(self):
        """Gets the cluster_config of this ItemForListClustersOutput.  # noqa: E501


        :return: The cluster_config of this ItemForListClustersOutput.  # noqa: E501
        :rtype: ClusterConfigForListClustersOutput
        """
        return self._cluster_config

    @cluster_config.setter
    def cluster_config(self, cluster_config):
        """Sets the cluster_config of this ItemForListClustersOutput.


        :param cluster_config: The cluster_config of this ItemForListClustersOutput.  # noqa: E501
        :type: ClusterConfigForListClustersOutput
        """

        self._cluster_config = cluster_config

    @property
    def create_client_token(self):
        """Gets the create_client_token of this ItemForListClustersOutput.  # noqa: E501


        :return: The create_client_token of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_client_token

    @create_client_token.setter
    def create_client_token(self, create_client_token):
        """Sets the create_client_token of this ItemForListClustersOutput.


        :param create_client_token: The create_client_token of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._create_client_token = create_client_token

    @property
    def create_time(self):
        """Gets the create_time of this ItemForListClustersOutput.  # noqa: E501


        :return: The create_time of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ItemForListClustersOutput.


        :param create_time: The create_time of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def delete_protection_enabled(self):
        """Gets the delete_protection_enabled of this ItemForListClustersOutput.  # noqa: E501


        :return: The delete_protection_enabled of this ItemForListClustersOutput.  # noqa: E501
        :rtype: bool
        """
        return self._delete_protection_enabled

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, delete_protection_enabled):
        """Sets the delete_protection_enabled of this ItemForListClustersOutput.


        :param delete_protection_enabled: The delete_protection_enabled of this ItemForListClustersOutput.  # noqa: E501
        :type: bool
        """

        self._delete_protection_enabled = delete_protection_enabled

    @property
    def description(self):
        """Gets the description of this ItemForListClustersOutput.  # noqa: E501


        :return: The description of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ItemForListClustersOutput.


        :param description: The description of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this ItemForListClustersOutput.  # noqa: E501


        :return: The id of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ItemForListClustersOutput.


        :param id: The id of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def kubernetes_version(self):
        """Gets the kubernetes_version of this ItemForListClustersOutput.  # noqa: E501


        :return: The kubernetes_version of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._kubernetes_version

    @kubernetes_version.setter
    def kubernetes_version(self, kubernetes_version):
        """Sets the kubernetes_version of this ItemForListClustersOutput.


        :param kubernetes_version: The kubernetes_version of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._kubernetes_version = kubernetes_version

    @property
    def name(self):
        """Gets the name of this ItemForListClustersOutput.  # noqa: E501


        :return: The name of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ItemForListClustersOutput.


        :param name: The name of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def node_statistics(self):
        """Gets the node_statistics of this ItemForListClustersOutput.  # noqa: E501


        :return: The node_statistics of this ItemForListClustersOutput.  # noqa: E501
        :rtype: NodeStatisticsForListClustersOutput
        """
        return self._node_statistics

    @node_statistics.setter
    def node_statistics(self, node_statistics):
        """Sets the node_statistics of this ItemForListClustersOutput.


        :param node_statistics: The node_statistics of this ItemForListClustersOutput.  # noqa: E501
        :type: NodeStatisticsForListClustersOutput
        """

        self._node_statistics = node_statistics

    @property
    def pods_config(self):
        """Gets the pods_config of this ItemForListClustersOutput.  # noqa: E501


        :return: The pods_config of this ItemForListClustersOutput.  # noqa: E501
        :rtype: PodsConfigForListClustersOutput
        """
        return self._pods_config

    @pods_config.setter
    def pods_config(self, pods_config):
        """Sets the pods_config of this ItemForListClustersOutput.


        :param pods_config: The pods_config of this ItemForListClustersOutput.  # noqa: E501
        :type: PodsConfigForListClustersOutput
        """

        self._pods_config = pods_config

    @property
    def services_config(self):
        """Gets the services_config of this ItemForListClustersOutput.  # noqa: E501


        :return: The services_config of this ItemForListClustersOutput.  # noqa: E501
        :rtype: ServicesConfigForListClustersOutput
        """
        return self._services_config

    @services_config.setter
    def services_config(self, services_config):
        """Sets the services_config of this ItemForListClustersOutput.


        :param services_config: The services_config of this ItemForListClustersOutput.  # noqa: E501
        :type: ServicesConfigForListClustersOutput
        """

        self._services_config = services_config

    @property
    def status(self):
        """Gets the status of this ItemForListClustersOutput.  # noqa: E501


        :return: The status of this ItemForListClustersOutput.  # noqa: E501
        :rtype: StatusForListClustersOutput
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ItemForListClustersOutput.


        :param status: The status of this ItemForListClustersOutput.  # noqa: E501
        :type: StatusForListClustersOutput
        """

        self._status = status

    @property
    def tags(self):
        """Gets the tags of this ItemForListClustersOutput.  # noqa: E501


        :return: The tags of this ItemForListClustersOutput.  # noqa: E501
        :rtype: list[TagForListClustersOutput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ItemForListClustersOutput.


        :param tags: The tags of this ItemForListClustersOutput.  # noqa: E501
        :type: list[TagForListClustersOutput]
        """

        self._tags = tags

    @property
    def update_client_token(self):
        """Gets the update_client_token of this ItemForListClustersOutput.  # noqa: E501


        :return: The update_client_token of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_client_token

    @update_client_token.setter
    def update_client_token(self, update_client_token):
        """Sets the update_client_token of this ItemForListClustersOutput.


        :param update_client_token: The update_client_token of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._update_client_token = update_client_token

    @property
    def update_time(self):
        """Gets the update_time of this ItemForListClustersOutput.  # noqa: E501


        :return: The update_time of this ItemForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this ItemForListClustersOutput.


        :param update_time: The update_time of this ItemForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemForListClustersOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemForListClustersOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemForListClustersOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    mongodb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class NodeSpecForDescribeNodeSpecsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_num': 'float',
        'max_conn': 'int',
        'max_storage': 'int',
        'mem_in_gb': 'float',
        'spec_name': 'str'
    }

    attribute_map = {
        'cpu_num': 'CpuNum',
        'max_conn': 'MaxConn',
        'max_storage': 'MaxStorage',
        'mem_in_gb': 'MemInGb',
        'spec_name': 'SpecName'
    }

    def __init__(self, cpu_num=None, max_conn=None, max_storage=None, mem_in_gb=None, spec_name=None, _configuration=None):  # noqa: E501
        """NodeSpecForDescribeNodeSpecsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu_num = None
        self._max_conn = None
        self._max_storage = None
        self._mem_in_gb = None
        self._spec_name = None
        self.discriminator = None

        if cpu_num is not None:
            self.cpu_num = cpu_num
        if max_conn is not None:
            self.max_conn = max_conn
        if max_storage is not None:
            self.max_storage = max_storage
        if mem_in_gb is not None:
            self.mem_in_gb = mem_in_gb
        if spec_name is not None:
            self.spec_name = spec_name

    @property
    def cpu_num(self):
        """Gets the cpu_num of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501


        :return: The cpu_num of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :rtype: float
        """
        return self._cpu_num

    @cpu_num.setter
    def cpu_num(self, cpu_num):
        """Sets the cpu_num of this NodeSpecForDescribeNodeSpecsOutput.


        :param cpu_num: The cpu_num of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :type: float
        """

        self._cpu_num = cpu_num

    @property
    def max_conn(self):
        """Gets the max_conn of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501


        :return: The max_conn of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :rtype: int
        """
        return self._max_conn

    @max_conn.setter
    def max_conn(self, max_conn):
        """Sets the max_conn of this NodeSpecForDescribeNodeSpecsOutput.


        :param max_conn: The max_conn of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :type: int
        """

        self._max_conn = max_conn

    @property
    def max_storage(self):
        """Gets the max_storage of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501


        :return: The max_storage of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :rtype: int
        """
        return self._max_storage

    @max_storage.setter
    def max_storage(self, max_storage):
        """Sets the max_storage of this NodeSpecForDescribeNodeSpecsOutput.


        :param max_storage: The max_storage of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :type: int
        """

        self._max_storage = max_storage

    @property
    def mem_in_gb(self):
        """Gets the mem_in_gb of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501


        :return: The mem_in_gb of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :rtype: float
        """
        return self._mem_in_gb

    @mem_in_gb.setter
    def mem_in_gb(self, mem_in_gb):
        """Sets the mem_in_gb of this NodeSpecForDescribeNodeSpecsOutput.


        :param mem_in_gb: The mem_in_gb of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :type: float
        """

        self._mem_in_gb = mem_in_gb

    @property
    def spec_name(self):
        """Gets the spec_name of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501


        :return: The spec_name of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :rtype: str
        """
        return self._spec_name

    @spec_name.setter
    def spec_name(self, spec_name):
        """Sets the spec_name of this NodeSpecForDescribeNodeSpecsOutput.


        :param spec_name: The spec_name of this NodeSpecForDescribeNodeSpecsOutput.  # noqa: E501
        :type: str
        """

        self._spec_name = spec_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeSpecForDescribeNodeSpecsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeSpecForDescribeNodeSpecsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NodeSpecForDescribeNodeSpecsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ItemForListNodesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_container_storage_enabled': 'bool',
        'cluster_id': 'str',
        'container_storage_path': 'str',
        'create_client_token': 'str',
        'create_time': 'str',
        'id': 'str',
        'initialize_script': 'str',
        'instance_id': 'str',
        'is_virtual': 'bool',
        'kubernetes_config': 'KubernetesConfigForListNodesOutput',
        'name': 'str',
        'node_pool_id': 'str',
        'roles': 'list[str]',
        'status': 'StatusForListNodesOutput',
        'update_time': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'additional_container_storage_enabled': 'AdditionalContainerStorageEnabled',
        'cluster_id': 'ClusterId',
        'container_storage_path': 'ContainerStoragePath',
        'create_client_token': 'CreateClientToken',
        'create_time': 'CreateTime',
        'id': 'Id',
        'initialize_script': 'InitializeScript',
        'instance_id': 'InstanceId',
        'is_virtual': 'IsVirtual',
        'kubernetes_config': 'KubernetesConfig',
        'name': 'Name',
        'node_pool_id': 'NodePoolId',
        'roles': 'Roles',
        'status': 'Status',
        'update_time': 'UpdateTime',
        'zone_id': 'ZoneId'
    }

    def __init__(self, additional_container_storage_enabled=None, cluster_id=None, container_storage_path=None, create_client_token=None, create_time=None, id=None, initialize_script=None, instance_id=None, is_virtual=None, kubernetes_config=None, name=None, node_pool_id=None, roles=None, status=None, update_time=None, zone_id=None, _configuration=None):  # noqa: E501
        """ItemForListNodesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._additional_container_storage_enabled = None
        self._cluster_id = None
        self._container_storage_path = None
        self._create_client_token = None
        self._create_time = None
        self._id = None
        self._initialize_script = None
        self._instance_id = None
        self._is_virtual = None
        self._kubernetes_config = None
        self._name = None
        self._node_pool_id = None
        self._roles = None
        self._status = None
        self._update_time = None
        self._zone_id = None
        self.discriminator = None

        if additional_container_storage_enabled is not None:
            self.additional_container_storage_enabled = additional_container_storage_enabled
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if container_storage_path is not None:
            self.container_storage_path = container_storage_path
        if create_client_token is not None:
            self.create_client_token = create_client_token
        if create_time is not None:
            self.create_time = create_time
        if id is not None:
            self.id = id
        if initialize_script is not None:
            self.initialize_script = initialize_script
        if instance_id is not None:
            self.instance_id = instance_id
        if is_virtual is not None:
            self.is_virtual = is_virtual
        if kubernetes_config is not None:
            self.kubernetes_config = kubernetes_config
        if name is not None:
            self.name = name
        if node_pool_id is not None:
            self.node_pool_id = node_pool_id
        if roles is not None:
            self.roles = roles
        if status is not None:
            self.status = status
        if update_time is not None:
            self.update_time = update_time
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def additional_container_storage_enabled(self):
        """Gets the additional_container_storage_enabled of this ItemForListNodesOutput.  # noqa: E501


        :return: The additional_container_storage_enabled of this ItemForListNodesOutput.  # noqa: E501
        :rtype: bool
        """
        return self._additional_container_storage_enabled

    @additional_container_storage_enabled.setter
    def additional_container_storage_enabled(self, additional_container_storage_enabled):
        """Sets the additional_container_storage_enabled of this ItemForListNodesOutput.


        :param additional_container_storage_enabled: The additional_container_storage_enabled of this ItemForListNodesOutput.  # noqa: E501
        :type: bool
        """

        self._additional_container_storage_enabled = additional_container_storage_enabled

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ItemForListNodesOutput.  # noqa: E501


        :return: The cluster_id of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ItemForListNodesOutput.


        :param cluster_id: The cluster_id of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def container_storage_path(self):
        """Gets the container_storage_path of this ItemForListNodesOutput.  # noqa: E501


        :return: The container_storage_path of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._container_storage_path

    @container_storage_path.setter
    def container_storage_path(self, container_storage_path):
        """Sets the container_storage_path of this ItemForListNodesOutput.


        :param container_storage_path: The container_storage_path of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._container_storage_path = container_storage_path

    @property
    def create_client_token(self):
        """Gets the create_client_token of this ItemForListNodesOutput.  # noqa: E501


        :return: The create_client_token of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_client_token

    @create_client_token.setter
    def create_client_token(self, create_client_token):
        """Sets the create_client_token of this ItemForListNodesOutput.


        :param create_client_token: The create_client_token of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._create_client_token = create_client_token

    @property
    def create_time(self):
        """Gets the create_time of this ItemForListNodesOutput.  # noqa: E501


        :return: The create_time of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ItemForListNodesOutput.


        :param create_time: The create_time of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def id(self):
        """Gets the id of this ItemForListNodesOutput.  # noqa: E501


        :return: The id of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ItemForListNodesOutput.


        :param id: The id of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def initialize_script(self):
        """Gets the initialize_script of this ItemForListNodesOutput.  # noqa: E501


        :return: The initialize_script of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._initialize_script

    @initialize_script.setter
    def initialize_script(self, initialize_script):
        """Sets the initialize_script of this ItemForListNodesOutput.


        :param initialize_script: The initialize_script of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._initialize_script = initialize_script

    @property
    def instance_id(self):
        """Gets the instance_id of this ItemForListNodesOutput.  # noqa: E501


        :return: The instance_id of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ItemForListNodesOutput.


        :param instance_id: The instance_id of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def is_virtual(self):
        """Gets the is_virtual of this ItemForListNodesOutput.  # noqa: E501


        :return: The is_virtual of this ItemForListNodesOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_virtual

    @is_virtual.setter
    def is_virtual(self, is_virtual):
        """Sets the is_virtual of this ItemForListNodesOutput.


        :param is_virtual: The is_virtual of this ItemForListNodesOutput.  # noqa: E501
        :type: bool
        """

        self._is_virtual = is_virtual

    @property
    def kubernetes_config(self):
        """Gets the kubernetes_config of this ItemForListNodesOutput.  # noqa: E501


        :return: The kubernetes_config of this ItemForListNodesOutput.  # noqa: E501
        :rtype: KubernetesConfigForListNodesOutput
        """
        return self._kubernetes_config

    @kubernetes_config.setter
    def kubernetes_config(self, kubernetes_config):
        """Sets the kubernetes_config of this ItemForListNodesOutput.


        :param kubernetes_config: The kubernetes_config of this ItemForListNodesOutput.  # noqa: E501
        :type: KubernetesConfigForListNodesOutput
        """

        self._kubernetes_config = kubernetes_config

    @property
    def name(self):
        """Gets the name of this ItemForListNodesOutput.  # noqa: E501


        :return: The name of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ItemForListNodesOutput.


        :param name: The name of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def node_pool_id(self):
        """Gets the node_pool_id of this ItemForListNodesOutput.  # noqa: E501


        :return: The node_pool_id of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_pool_id

    @node_pool_id.setter
    def node_pool_id(self, node_pool_id):
        """Sets the node_pool_id of this ItemForListNodesOutput.


        :param node_pool_id: The node_pool_id of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._node_pool_id = node_pool_id

    @property
    def roles(self):
        """Gets the roles of this ItemForListNodesOutput.  # noqa: E501


        :return: The roles of this ItemForListNodesOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this ItemForListNodesOutput.


        :param roles: The roles of this ItemForListNodesOutput.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["Etcd", "Master", "Worker"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(roles).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `roles` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(roles) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._roles = roles

    @property
    def status(self):
        """Gets the status of this ItemForListNodesOutput.  # noqa: E501


        :return: The status of this ItemForListNodesOutput.  # noqa: E501
        :rtype: StatusForListNodesOutput
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ItemForListNodesOutput.


        :param status: The status of this ItemForListNodesOutput.  # noqa: E501
        :type: StatusForListNodesOutput
        """

        self._status = status

    @property
    def update_time(self):
        """Gets the update_time of this ItemForListNodesOutput.  # noqa: E501


        :return: The update_time of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this ItemForListNodesOutput.


        :param update_time: The update_time of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def zone_id(self):
        """Gets the zone_id of this ItemForListNodesOutput.  # noqa: E501


        :return: The zone_id of this ItemForListNodesOutput.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this ItemForListNodesOutput.


        :param zone_id: The zone_id of this ItemForListNodesOutput.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemForListNodesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemForListNodesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemForListNodesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class UpdateClusterConfigRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'client_token': 'str',
        'cluster_config': 'ClusterConfigForUpdateClusterConfigInput',
        'delete_protection_enabled': 'bool',
        'description': 'str',
        'id': 'str',
        'name': 'str'
    }

    attribute_map = {
        'client_token': 'ClientToken',
        'cluster_config': 'ClusterConfig',
        'delete_protection_enabled': 'DeleteProtectionEnabled',
        'description': 'Description',
        'id': 'Id',
        'name': 'Name'
    }

    def __init__(self, client_token=None, cluster_config=None, delete_protection_enabled=None, description=None, id=None, name=None, _configuration=None):  # noqa: E501
        """UpdateClusterConfigRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._client_token = None
        self._cluster_config = None
        self._delete_protection_enabled = None
        self._description = None
        self._id = None
        self._name = None
        self.discriminator = None

        if client_token is not None:
            self.client_token = client_token
        if cluster_config is not None:
            self.cluster_config = cluster_config
        if delete_protection_enabled is not None:
            self.delete_protection_enabled = delete_protection_enabled
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name

    @property
    def client_token(self):
        """Gets the client_token of this UpdateClusterConfigRequest.  # noqa: E501


        :return: The client_token of this UpdateClusterConfigRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_token

    @client_token.setter
    def client_token(self, client_token):
        """Sets the client_token of this UpdateClusterConfigRequest.


        :param client_token: The client_token of this UpdateClusterConfigRequest.  # noqa: E501
        :type: str
        """

        self._client_token = client_token

    @property
    def cluster_config(self):
        """Gets the cluster_config of this UpdateClusterConfigRequest.  # noqa: E501


        :return: The cluster_config of this UpdateClusterConfigRequest.  # noqa: E501
        :rtype: ClusterConfigForUpdateClusterConfigInput
        """
        return self._cluster_config

    @cluster_config.setter
    def cluster_config(self, cluster_config):
        """Sets the cluster_config of this UpdateClusterConfigRequest.


        :param cluster_config: The cluster_config of this UpdateClusterConfigRequest.  # noqa: E501
        :type: ClusterConfigForUpdateClusterConfigInput
        """

        self._cluster_config = cluster_config

    @property
    def delete_protection_enabled(self):
        """Gets the delete_protection_enabled of this UpdateClusterConfigRequest.  # noqa: E501


        :return: The delete_protection_enabled of this UpdateClusterConfigRequest.  # noqa: E501
        :rtype: bool
        """
        return self._delete_protection_enabled

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, delete_protection_enabled):
        """Sets the delete_protection_enabled of this UpdateClusterConfigRequest.


        :param delete_protection_enabled: The delete_protection_enabled of this UpdateClusterConfigRequest.  # noqa: E501
        :type: bool
        """

        self._delete_protection_enabled = delete_protection_enabled

    @property
    def description(self):
        """Gets the description of this UpdateClusterConfigRequest.  # noqa: E501


        :return: The description of this UpdateClusterConfigRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateClusterConfigRequest.


        :param description: The description of this UpdateClusterConfigRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this UpdateClusterConfigRequest.  # noqa: E501


        :return: The id of this UpdateClusterConfigRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UpdateClusterConfigRequest.


        :param id: The id of this UpdateClusterConfigRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this UpdateClusterConfigRequest.  # noqa: E501


        :return: The name of this UpdateClusterConfigRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateClusterConfigRequest.


        :param name: The name of this UpdateClusterConfigRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateClusterConfigRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateClusterConfigRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateClusterConfigRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpc

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeEipAddressesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allocation_ids': 'list[str]',
        'associated_instance_id': 'str',
        'associated_instance_type': 'str',
        'billing_type': 'int',
        'eip_addresses': 'list[str]',
        'isp': 'str',
        'name': 'str',
        'page_number': 'int',
        'page_size': 'int',
        'project_name': 'str',
        'security_protection_enabled': 'bool',
        'status': 'str',
        'tag_filters': 'list[TagFilterForDescribeEipAddressesInput]'
    }

    attribute_map = {
        'allocation_ids': 'AllocationIds',
        'associated_instance_id': 'AssociatedInstanceId',
        'associated_instance_type': 'AssociatedInstanceType',
        'billing_type': 'BillingType',
        'eip_addresses': 'EipAddresses',
        'isp': 'ISP',
        'name': 'Name',
        'page_number': 'PageNumber',
        'page_size': 'PageSize',
        'project_name': 'ProjectName',
        'security_protection_enabled': 'SecurityProtectionEnabled',
        'status': 'Status',
        'tag_filters': 'TagFilters'
    }

    def __init__(self, allocation_ids=None, associated_instance_id=None, associated_instance_type=None, billing_type=None, eip_addresses=None, isp=None, name=None, page_number=None, page_size=None, project_name=None, security_protection_enabled=None, status=None, tag_filters=None, _configuration=None):  # noqa: E501
        """DescribeEipAddressesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._allocation_ids = None
        self._associated_instance_id = None
        self._associated_instance_type = None
        self._billing_type = None
        self._eip_addresses = None
        self._isp = None
        self._name = None
        self._page_number = None
        self._page_size = None
        self._project_name = None
        self._security_protection_enabled = None
        self._status = None
        self._tag_filters = None
        self.discriminator = None

        if allocation_ids is not None:
            self.allocation_ids = allocation_ids
        if associated_instance_id is not None:
            self.associated_instance_id = associated_instance_id
        if associated_instance_type is not None:
            self.associated_instance_type = associated_instance_type
        if billing_type is not None:
            self.billing_type = billing_type
        if eip_addresses is not None:
            self.eip_addresses = eip_addresses
        if isp is not None:
            self.isp = isp
        if name is not None:
            self.name = name
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if project_name is not None:
            self.project_name = project_name
        if security_protection_enabled is not None:
            self.security_protection_enabled = security_protection_enabled
        if status is not None:
            self.status = status
        if tag_filters is not None:
            self.tag_filters = tag_filters

    @property
    def allocation_ids(self):
        """Gets the allocation_ids of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The allocation_ids of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocation_ids

    @allocation_ids.setter
    def allocation_ids(self, allocation_ids):
        """Sets the allocation_ids of this DescribeEipAddressesRequest.


        :param allocation_ids: The allocation_ids of this DescribeEipAddressesRequest.  # noqa: E501
        :type: list[str]
        """

        self._allocation_ids = allocation_ids

    @property
    def associated_instance_id(self):
        """Gets the associated_instance_id of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The associated_instance_id of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: str
        """
        return self._associated_instance_id

    @associated_instance_id.setter
    def associated_instance_id(self, associated_instance_id):
        """Sets the associated_instance_id of this DescribeEipAddressesRequest.


        :param associated_instance_id: The associated_instance_id of this DescribeEipAddressesRequest.  # noqa: E501
        :type: str
        """

        self._associated_instance_id = associated_instance_id

    @property
    def associated_instance_type(self):
        """Gets the associated_instance_type of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The associated_instance_type of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: str
        """
        return self._associated_instance_type

    @associated_instance_type.setter
    def associated_instance_type(self, associated_instance_type):
        """Sets the associated_instance_type of this DescribeEipAddressesRequest.


        :param associated_instance_type: The associated_instance_type of this DescribeEipAddressesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Nat", "EcsInstance", "NetworkInterface", "ClbInstance", "AlbInstance"]  # noqa: E501
        if (self._configuration.client_side_validation and
                associated_instance_type not in allowed_values):
            raise ValueError(
                "Invalid value for `associated_instance_type` ({0}), must be one of {1}"  # noqa: E501
                .format(associated_instance_type, allowed_values)
            )

        self._associated_instance_type = associated_instance_type

    @property
    def billing_type(self):
        """Gets the billing_type of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The billing_type of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: int
        """
        return self._billing_type

    @billing_type.setter
    def billing_type(self, billing_type):
        """Sets the billing_type of this DescribeEipAddressesRequest.


        :param billing_type: The billing_type of this DescribeEipAddressesRequest.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                billing_type is not None and billing_type > 3):  # noqa: E501
            raise ValueError("Invalid value for `billing_type`, must be a value less than or equal to `3`")  # noqa: E501
        if (self._configuration.client_side_validation and
                billing_type is not None and billing_type < 1):  # noqa: E501
            raise ValueError("Invalid value for `billing_type`, must be a value greater than or equal to `1`")  # noqa: E501

        self._billing_type = billing_type

    @property
    def eip_addresses(self):
        """Gets the eip_addresses of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The eip_addresses of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._eip_addresses

    @eip_addresses.setter
    def eip_addresses(self, eip_addresses):
        """Sets the eip_addresses of this DescribeEipAddressesRequest.


        :param eip_addresses: The eip_addresses of this DescribeEipAddressesRequest.  # noqa: E501
        :type: list[str]
        """

        self._eip_addresses = eip_addresses

    @property
    def isp(self):
        """Gets the isp of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The isp of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: str
        """
        return self._isp

    @isp.setter
    def isp(self, isp):
        """Sets the isp of this DescribeEipAddressesRequest.


        :param isp: The isp of this DescribeEipAddressesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["BGP", "ChinaMobile", "ChinaUnicom", "ChinaTelecom"]  # noqa: E501
        if (self._configuration.client_side_validation and
                isp not in allowed_values):
            raise ValueError(
                "Invalid value for `isp` ({0}), must be one of {1}"  # noqa: E501
                .format(isp, allowed_values)
            )

        self._isp = isp

    @property
    def name(self):
        """Gets the name of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The name of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DescribeEipAddressesRequest.


        :param name: The name of this DescribeEipAddressesRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def page_number(self):
        """Gets the page_number of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The page_number of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this DescribeEipAddressesRequest.


        :param page_number: The page_number of this DescribeEipAddressesRequest.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The page_size of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DescribeEipAddressesRequest.


        :param page_size: The page_size of this DescribeEipAddressesRequest.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                page_size is not None and page_size > 100):  # noqa: E501
            raise ValueError("Invalid value for `page_size`, must be a value less than or equal to `100`")  # noqa: E501

        self._page_size = page_size

    @property
    def project_name(self):
        """Gets the project_name of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The project_name of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DescribeEipAddressesRequest.


        :param project_name: The project_name of this DescribeEipAddressesRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def security_protection_enabled(self):
        """Gets the security_protection_enabled of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The security_protection_enabled of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._security_protection_enabled

    @security_protection_enabled.setter
    def security_protection_enabled(self, security_protection_enabled):
        """Sets the security_protection_enabled of this DescribeEipAddressesRequest.


        :param security_protection_enabled: The security_protection_enabled of this DescribeEipAddressesRequest.  # noqa: E501
        :type: bool
        """

        self._security_protection_enabled = security_protection_enabled

    @property
    def status(self):
        """Gets the status of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The status of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeEipAddressesRequest.


        :param status: The status of this DescribeEipAddressesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Attaching", "Detaching", "Attached", "Available"]  # noqa: E501
        if (self._configuration.client_side_validation and
                status not in allowed_values):
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def tag_filters(self):
        """Gets the tag_filters of this DescribeEipAddressesRequest.  # noqa: E501


        :return: The tag_filters of this DescribeEipAddressesRequest.  # noqa: E501
        :rtype: list[TagFilterForDescribeEipAddressesInput]
        """
        return self._tag_filters

    @tag_filters.setter
    def tag_filters(self, tag_filters):
        """Sets the tag_filters of this DescribeEipAddressesRequest.


        :param tag_filters: The tag_filters of this DescribeEipAddressesRequest.  # noqa: E501
        :type: list[TagFilterForDescribeEipAddressesInput]
        """

        self._tag_filters = tag_filters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeEipAddressesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeEipAddressesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeEipAddressesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class SlowQueryForDescribeSlowLogsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'db_name': 'str',
        'execution_start_time': 'str',
        'host_address': 'str',
        'instance_id': 'str',
        'node_id': 'str',
        'query_text': 'str',
        'query_times': 'int',
        'user_name': 'str'
    }

    attribute_map = {
        'db_name': 'DBName',
        'execution_start_time': 'ExecutionStartTime',
        'host_address': 'HostAddress',
        'instance_id': 'InstanceId',
        'node_id': 'NodeId',
        'query_text': 'QueryText',
        'query_times': 'QueryTimes',
        'user_name': 'UserName'
    }

    def __init__(self, db_name=None, execution_start_time=None, host_address=None, instance_id=None, node_id=None, query_text=None, query_times=None, user_name=None, _configuration=None):  # noqa: E501
        """SlowQueryForDescribeSlowLogsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._db_name = None
        self._execution_start_time = None
        self._host_address = None
        self._instance_id = None
        self._node_id = None
        self._query_text = None
        self._query_times = None
        self._user_name = None
        self.discriminator = None

        if db_name is not None:
            self.db_name = db_name
        if execution_start_time is not None:
            self.execution_start_time = execution_start_time
        if host_address is not None:
            self.host_address = host_address
        if instance_id is not None:
            self.instance_id = instance_id
        if node_id is not None:
            self.node_id = node_id
        if query_text is not None:
            self.query_text = query_text
        if query_times is not None:
            self.query_times = query_times
        if user_name is not None:
            self.user_name = user_name

    @property
    def db_name(self):
        """Gets the db_name of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501


        :return: The db_name of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """Sets the db_name of this SlowQueryForDescribeSlowLogsOutput.


        :param db_name: The db_name of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :type: str
        """

        self._db_name = db_name

    @property
    def execution_start_time(self):
        """Gets the execution_start_time of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501


        :return: The execution_start_time of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :rtype: str
        """
        return self._execution_start_time

    @execution_start_time.setter
    def execution_start_time(self, execution_start_time):
        """Sets the execution_start_time of this SlowQueryForDescribeSlowLogsOutput.


        :param execution_start_time: The execution_start_time of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :type: str
        """

        self._execution_start_time = execution_start_time

    @property
    def host_address(self):
        """Gets the host_address of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501


        :return: The host_address of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :rtype: str
        """
        return self._host_address

    @host_address.setter
    def host_address(self, host_address):
        """Sets the host_address of this SlowQueryForDescribeSlowLogsOutput.


        :param host_address: The host_address of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :type: str
        """

        self._host_address = host_address

    @property
    def instance_id(self):
        """Gets the instance_id of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501


        :return: The instance_id of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this SlowQueryForDescribeSlowLogsOutput.


        :param instance_id: The instance_id of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def node_id(self):
        """Gets the node_id of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501


        :return: The node_id of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this SlowQueryForDescribeSlowLogsOutput.


        :param node_id: The node_id of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def query_text(self):
        """Gets the query_text of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501


        :return: The query_text of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :rtype: str
        """
        return self._query_text

    @query_text.setter
    def query_text(self, query_text):
        """Sets the query_text of this SlowQueryForDescribeSlowLogsOutput.


        :param query_text: The query_text of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :type: str
        """

        self._query_text = query_text

    @property
    def query_times(self):
        """Gets the query_times of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501


        :return: The query_times of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :rtype: int
        """
        return self._query_times

    @query_times.setter
    def query_times(self, query_times):
        """Sets the query_times of this SlowQueryForDescribeSlowLogsOutput.


        :param query_times: The query_times of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :type: int
        """

        self._query_times = query_times

    @property
    def user_name(self):
        """Gets the user_name of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501


        :return: The user_name of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this SlowQueryForDescribeSlowLogsOutput.


        :param user_name: The user_name of this SlowQueryForDescribeSlowLogsOutput.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SlowQueryForDescribeSlowLogsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SlowQueryForDescribeSlowLogsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SlowQueryForDescribeSlowLogsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ScalingConfigurationForDescribeScalingConfigurationsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'eip': 'EipForDescribeScalingConfigurationsOutput',
        'host_name': 'str',
        'image_id': 'str',
        'instance_description': 'str',
        'instance_name': 'str',
        'instance_types': 'list[str]',
        'key_pair_name': 'str',
        'lifecycle_state': 'str',
        'scaling_configuration_id': 'str',
        'scaling_configuration_name': 'str',
        'scaling_group_id': 'str',
        'security_enhancement_strategy': 'str',
        'security_group_ids': 'list[str]',
        'updated_at': 'str',
        'user_data': 'str',
        'volumes': 'list[VolumeForDescribeScalingConfigurationsOutput]',
        'zone_id': 'str'
    }

    attribute_map = {
        'created_at': 'CreatedAt',
        'eip': 'Eip',
        'host_name': 'HostName',
        'image_id': 'ImageId',
        'instance_description': 'InstanceDescription',
        'instance_name': 'InstanceName',
        'instance_types': 'InstanceTypes',
        'key_pair_name': 'KeyPairName',
        'lifecycle_state': 'LifecycleState',
        'scaling_configuration_id': 'ScalingConfigurationId',
        'scaling_configuration_name': 'ScalingConfigurationName',
        'scaling_group_id': 'ScalingGroupId',
        'security_enhancement_strategy': 'SecurityEnhancementStrategy',
        'security_group_ids': 'SecurityGroupIds',
        'updated_at': 'UpdatedAt',
        'user_data': 'UserData',
        'volumes': 'Volumes',
        'zone_id': 'ZoneId'
    }

    def __init__(self, created_at=None, eip=None, host_name=None, image_id=None, instance_description=None, instance_name=None, instance_types=None, key_pair_name=None, lifecycle_state=None, scaling_configuration_id=None, scaling_configuration_name=None, scaling_group_id=None, security_enhancement_strategy=None, security_group_ids=None, updated_at=None, user_data=None, volumes=None, zone_id=None, _configuration=None):  # noqa: E501
        """ScalingConfigurationForDescribeScalingConfigurationsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._created_at = None
        self._eip = None
        self._host_name = None
        self._image_id = None
        self._instance_description = None
        self._instance_name = None
        self._instance_types = None
        self._key_pair_name = None
        self._lifecycle_state = None
        self._scaling_configuration_id = None
        self._scaling_configuration_name = None
        self._scaling_group_id = None
        self._security_enhancement_strategy = None
        self._security_group_ids = None
        self._updated_at = None
        self._user_data = None
        self._volumes = None
        self._zone_id = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if eip is not None:
            self.eip = eip
        if host_name is not None:
            self.host_name = host_name
        if image_id is not None:
            self.image_id = image_id
        if instance_description is not None:
            self.instance_description = instance_description
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_types is not None:
            self.instance_types = instance_types
        if key_pair_name is not None:
            self.key_pair_name = key_pair_name
        if lifecycle_state is not None:
            self.lifecycle_state = lifecycle_state
        if scaling_configuration_id is not None:
            self.scaling_configuration_id = scaling_configuration_id
        if scaling_configuration_name is not None:
            self.scaling_configuration_name = scaling_configuration_name
        if scaling_group_id is not None:
            self.scaling_group_id = scaling_group_id
        if security_enhancement_strategy is not None:
            self.security_enhancement_strategy = security_enhancement_strategy
        if security_group_ids is not None:
            self.security_group_ids = security_group_ids
        if updated_at is not None:
            self.updated_at = updated_at
        if user_data is not None:
            self.user_data = user_data
        if volumes is not None:
            self.volumes = volumes
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def created_at(self):
        """Gets the created_at of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The created_at of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param created_at: The created_at of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def eip(self):
        """Gets the eip of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The eip of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: EipForDescribeScalingConfigurationsOutput
        """
        return self._eip

    @eip.setter
    def eip(self, eip):
        """Sets the eip of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param eip: The eip of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: EipForDescribeScalingConfigurationsOutput
        """

        self._eip = eip

    @property
    def host_name(self):
        """Gets the host_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The host_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """Sets the host_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param host_name: The host_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._host_name = host_name

    @property
    def image_id(self):
        """Gets the image_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The image_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param image_id: The image_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def instance_description(self):
        """Gets the instance_description of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The instance_description of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_description

    @instance_description.setter
    def instance_description(self, instance_description):
        """Sets the instance_description of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param instance_description: The instance_description of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._instance_description = instance_description

    @property
    def instance_name(self):
        """Gets the instance_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The instance_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param instance_name: The instance_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_types(self):
        """Gets the instance_types of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The instance_types of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._instance_types

    @instance_types.setter
    def instance_types(self, instance_types):
        """Sets the instance_types of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param instance_types: The instance_types of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: list[str]
        """

        self._instance_types = instance_types

    @property
    def key_pair_name(self):
        """Gets the key_pair_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The key_pair_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._key_pair_name

    @key_pair_name.setter
    def key_pair_name(self, key_pair_name):
        """Sets the key_pair_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param key_pair_name: The key_pair_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._key_pair_name = key_pair_name

    @property
    def lifecycle_state(self):
        """Gets the lifecycle_state of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The lifecycle_state of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """Sets the lifecycle_state of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param lifecycle_state: The lifecycle_state of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._lifecycle_state = lifecycle_state

    @property
    def scaling_configuration_id(self):
        """Gets the scaling_configuration_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The scaling_configuration_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_configuration_id

    @scaling_configuration_id.setter
    def scaling_configuration_id(self, scaling_configuration_id):
        """Sets the scaling_configuration_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param scaling_configuration_id: The scaling_configuration_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._scaling_configuration_id = scaling_configuration_id

    @property
    def scaling_configuration_name(self):
        """Gets the scaling_configuration_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The scaling_configuration_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_configuration_name

    @scaling_configuration_name.setter
    def scaling_configuration_name(self, scaling_configuration_name):
        """Sets the scaling_configuration_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param scaling_configuration_name: The scaling_configuration_name of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._scaling_configuration_name = scaling_configuration_name

    @property
    def scaling_group_id(self):
        """Gets the scaling_group_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The scaling_group_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_group_id

    @scaling_group_id.setter
    def scaling_group_id(self, scaling_group_id):
        """Sets the scaling_group_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param scaling_group_id: The scaling_group_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._scaling_group_id = scaling_group_id

    @property
    def security_enhancement_strategy(self):
        """Gets the security_enhancement_strategy of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The security_enhancement_strategy of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._security_enhancement_strategy

    @security_enhancement_strategy.setter
    def security_enhancement_strategy(self, security_enhancement_strategy):
        """Sets the security_enhancement_strategy of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param security_enhancement_strategy: The security_enhancement_strategy of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._security_enhancement_strategy = security_enhancement_strategy

    @property
    def security_group_ids(self):
        """Gets the security_group_ids of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The security_group_ids of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._security_group_ids

    @security_group_ids.setter
    def security_group_ids(self, security_group_ids):
        """Sets the security_group_ids of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param security_group_ids: The security_group_ids of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: list[str]
        """

        self._security_group_ids = security_group_ids

    @property
    def updated_at(self):
        """Gets the updated_at of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The updated_at of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param updated_at: The updated_at of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def user_data(self):
        """Gets the user_data of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The user_data of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._user_data

    @user_data.setter
    def user_data(self, user_data):
        """Sets the user_data of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param user_data: The user_data of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._user_data = user_data

    @property
    def volumes(self):
        """Gets the volumes of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The volumes of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: list[VolumeForDescribeScalingConfigurationsOutput]
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param volumes: The volumes of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: list[VolumeForDescribeScalingConfigurationsOutput]
        """

        self._volumes = volumes

    @property
    def zone_id(self):
        """Gets the zone_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501


        :return: The zone_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.


        :param zone_id: The zone_id of this ScalingConfigurationForDescribeScalingConfigurationsOutput.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScalingConfigurationForDescribeScalingConfigurationsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScalingConfigurationForDescribeScalingConfigurationsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScalingConfigurationForDescribeScalingConfigurationsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ConnectionInfoForDescribeDBInstanceOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enable_read_only': 'str',
        'enable_read_write_splitting': 'str',
        'internal_domain': 'str',
        'internal_port': 'str',
        'public_domain': 'str',
        'public_port': 'str'
    }

    attribute_map = {
        'enable_read_only': 'EnableReadOnly',
        'enable_read_write_splitting': 'EnableReadWriteSplitting',
        'internal_domain': 'InternalDomain',
        'internal_port': 'InternalPort',
        'public_domain': 'PublicDomain',
        'public_port': 'PublicPort'
    }

    def __init__(self, enable_read_only=None, enable_read_write_splitting=None, internal_domain=None, internal_port=None, public_domain=None, public_port=None, _configuration=None):  # noqa: E501
        """ConnectionInfoForDescribeDBInstanceOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._enable_read_only = None
        self._enable_read_write_splitting = None
        self._internal_domain = None
        self._internal_port = None
        self._public_domain = None
        self._public_port = None
        self.discriminator = None

        if enable_read_only is not None:
            self.enable_read_only = enable_read_only
        if enable_read_write_splitting is not None:
            self.enable_read_write_splitting = enable_read_write_splitting
        if internal_domain is not None:
            self.internal_domain = internal_domain
        if internal_port is not None:
            self.internal_port = internal_port
        if public_domain is not None:
            self.public_domain = public_domain
        if public_port is not None:
            self.public_port = public_port

    @property
    def enable_read_only(self):
        """Gets the enable_read_only of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The enable_read_only of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._enable_read_only

    @enable_read_only.setter
    def enable_read_only(self, enable_read_only):
        """Sets the enable_read_only of this ConnectionInfoForDescribeDBInstanceOutput.


        :param enable_read_only: The enable_read_only of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["Disable", "Enable"]  # noqa: E501
        if (self._configuration.client_side_validation and
                enable_read_only not in allowed_values):
            raise ValueError(
                "Invalid value for `enable_read_only` ({0}), must be one of {1}"  # noqa: E501
                .format(enable_read_only, allowed_values)
            )

        self._enable_read_only = enable_read_only

    @property
    def enable_read_write_splitting(self):
        """Gets the enable_read_write_splitting of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The enable_read_write_splitting of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._enable_read_write_splitting

    @enable_read_write_splitting.setter
    def enable_read_write_splitting(self, enable_read_write_splitting):
        """Sets the enable_read_write_splitting of this ConnectionInfoForDescribeDBInstanceOutput.


        :param enable_read_write_splitting: The enable_read_write_splitting of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["Disable", "Enable"]  # noqa: E501
        if (self._configuration.client_side_validation and
                enable_read_write_splitting not in allowed_values):
            raise ValueError(
                "Invalid value for `enable_read_write_splitting` ({0}), must be one of {1}"  # noqa: E501
                .format(enable_read_write_splitting, allowed_values)
            )

        self._enable_read_write_splitting = enable_read_write_splitting

    @property
    def internal_domain(self):
        """Gets the internal_domain of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The internal_domain of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._internal_domain

    @internal_domain.setter
    def internal_domain(self, internal_domain):
        """Sets the internal_domain of this ConnectionInfoForDescribeDBInstanceOutput.


        :param internal_domain: The internal_domain of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._internal_domain = internal_domain

    @property
    def internal_port(self):
        """Gets the internal_port of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The internal_port of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._internal_port

    @internal_port.setter
    def internal_port(self, internal_port):
        """Sets the internal_port of this ConnectionInfoForDescribeDBInstanceOutput.


        :param internal_port: The internal_port of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._internal_port = internal_port

    @property
    def public_domain(self):
        """Gets the public_domain of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The public_domain of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._public_domain

    @public_domain.setter
    def public_domain(self, public_domain):
        """Sets the public_domain of this ConnectionInfoForDescribeDBInstanceOutput.


        :param public_domain: The public_domain of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._public_domain = public_domain

    @property
    def public_port(self):
        """Gets the public_port of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The public_port of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._public_port

    @public_port.setter
    def public_port(self, public_port):
        """Sets the public_port of this ConnectionInfoForDescribeDBInstanceOutput.


        :param public_port: The public_port of this ConnectionInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._public_port = public_port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConnectionInfoForDescribeDBInstanceOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectionInfoForDescribeDBInstanceOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectionInfoForDescribeDBInstanceOutput):
            return True

        return self.to_dict() != other.to_dict()
